#===============================================================================
# jsontab.py
#===============================================================================

"""Agnostically load JSON or tabular data"""




# Imports ======================================================================

import json
import pandas as pd




# Functions ====================================================================

def from_json(
    filename_or_buffer,
    orient='columns',
    dtype=None,
    columns=None,
    **kwargs
):
    """Load a data frame from JSON data

    Parameters
    ----------
    filepath_or_buffer
        file path or buffer providing JSON data
    orient
        passed to pandas.DataFrame.from_dict()
    dtype
        passed to pandas.DataFrame.from_dict()
    columns
        passed to pandas.DataFrame.from_dict()
    kwargs
        other arguments passed to json.load()
    
    Returns
    -------
    DataFrame
        a pandas data frame
    """

    return pd.DataFrame.from_dict(
        json.load(filename_or_buffer, **kwargs),
        orient=orient,
        dtype=dtype,
        columns=columns
    )


def from_json_or_tab(
    filename_or_buffer,
    json=False,
    tab=False,
    orient='columns',
    dtype=None,
    columns=None,
    **kwargs
):
    """Agnostically load JSON or tabular data

    Parameters
    ----------
    filepath_or_buffer
        a JSON or tabular file or buffer
    json : bool
        if True, expect JSON input
    tab : bool
        if True, expect tabular input
    header : bool
        if True, input file has a header
    kwargs
        other arguments passed to json.load() or pandas.read_csv()
    
    Returns
    -------
    DataFrame
        a pandas data frame
    """

    if json and not tab:
        return from_json(
            filename_or_buffer,
            orient=orient,
            dtype=dtype,
            columns=columns,
            **kwargs
        )
    elif tab and not json:
        return pd.read_csv(filename_or_buffer, **kwargs)
    else:
        try:
            return from_json(
                filename_or_buffer,
                orient=orient,
                dtype=dtype,
                columns=columns,
                **kwargs
            )
        except:
            return pd.read_csv(filename_or_buffer, **kwargs)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='betabernsum',
    version='0.0.1',
    author='Anthony Aylward',
    author_email='aaylward@eng.ucsd.edu',
    description='Agnostically load JSON or tabular data',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/anthony-aylward/betabernsum.git',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    install_requires=['pandas']
)
